# myterial
Just an easy way to access material colors' hex codes

### Installation
```
pip install myterial
```


### Usage
```python
from myterial import salmon
```

### Colors:
<img src='colors.PNG' width="600px"></img>
